# Bioturing Connector

Bioturing Connector is a Python package that provides an interface to interact with Bioturing's services. It includes connectors for BBrowserX, Lens Bulk, and Lens SC. Read the [documentation](https://sdk.bioturing.com/).

## Installation

You can install the Bioturing Connector using pip:

```bash
pip install bioturing-connector
```
